\name{SeqScore}

\alias{SeqScore}
\alias{SeqScore,RolexaRun-method}
\title{Fit and Plot intensities}
\description{Model-based classification of intensity data points, to
  either perform a base calling or generate diagnostic plots}
\usage{
\S4method{SeqScore}{RolexaRun}(run=Rolexa.env,int,seqInit,colonies,cycles,plot=FALSE)
SeqScore(run,...)
}
\arguments{
  \item{run}{a \code{RolexaRun} object defining the run parameters}
  \item{int}{a \code{\link[ShortRead:SolexaIntensity-class]{SolexaIntensity}}
    object}
  \item{seqInit}{a \code{\link[ShortRead:ShortRead-class]{ShortRead}} object}
  \item{colonies}{which colonies to select}
  \item{cycles}{which cycles to select}
  \item{plot}{if TRUE do a plot rather then perform a base-calling}
  \item{\dots}{additional arguments, ignored}
}
\details{
  This will use the EEV model of \link[mclust:mclustModelNames]{mclust} to fit the
  data clouds with a mixture of 4 gaussian distributions.
  and generate a list of tags and
  entropy scores for each sequenced colony (if \code{plot} is FALSE) or 
  plots two 2-dimensional projections for each selected
  cycle with gaussian parameters represented by standard ellipses and data
  points colored according to the induced classification.

  If \code{\link[=RolexaRun-class]{fit}} is TRUE, then the
  \link[mclust:meE]{EM} algorithm is run to convergencce, otherwise only
  an \link[mclust:estepE]{E-step} and an \link[mclust:mstepE]{M-step}
  are performed to evaluate the probabilities.
  
  The fitting procedure then uses
  \code{\link[=RolexaRun-class]{HThresholds}} to decide if a base is
  unambiguous and if degenerate IUPAC codes will be used.
}

\value{
  if \code{plot} is FALSE, \code{SeqScore} returns a list with an
  \code{id} slot containing the colonies coordinates, an
  \code{sread} slot which is a \code{\link[Biostrings:XStringSet-class]{DNAStringSet}}
  object and an \code{entropy} matrix}
\references{Probabilistic base calling of Solexa sequencing data,
  BMC Bioinformatics 2008, 9:431}
\author{Jacques Rougemont, Arnaud Amzallag, Christian Iseli, Laurent Farinelli, Ioannis Xenarios, Felix Naef}
\examples{
path = SolexaPath(system.file("extdata", package="ShortRead"))
rolenv = SetModel(idsep="_")
int = readIntensities(path,pattern="s_1_0001",withVariability=FALSE)
seq = CombineReads(run=rolenv,path=path,pattern="s_1_0001_seq*")
results = SeqScore(run=rolenv,int=int,seqInit=seq,cycles=1:10)
results$sread
}
\keyword{cluster}
\keyword{multivariate}
